@@ -1,14 +1,11 @@
 context("TEST: modeltime_fit_resamples()")
 
-library(testthat)
-
 # Machine Learning
 library(tidymodels)
 library(modeltime)
 library(modeltime.resample)
 
 # Core Packages
-library(tidyverse)
 library(timetk)
 library(lubridate)
 
